@@ -43,9 +43,15 @@ class CogEnvDecoder:
         self._reward = None
         self._done = None
         self._info = None
-        data = open("RealGame_Data/data.txt", "w")
-        data.write(str(mat_num))
-        data.close()
+        self._action = [0, 0, 0, 0]
+        if env_name == 'RealGame.exe':
+            data = open("RealGame_Data/data.txt", "w")
+            data.write(str(mat_num))
+            data.close()
+        elif env_name == '1.x86_64':
+            data = open("data.txt", "w")
+            data.write(str(mat_num))
+            data.close()
 
 
     @property
@@ -66,11 +72,11 @@ class CogEnvDecoder:
         return self._env.close()
 
     def reset(self):
-        #self._end_thread = True
-        #self._thread.join()
+        self._end_thread = True
+        self._thread.join()
         obs = self._env.reset()
-        #self._end_thread = False
-        #self.step_thread_begin()
+        self._end_thread = False
+        self.step_thread_begin()
         img = self.read_img()
         self_pos = self._GetSelfPos(obs)  # Blue one Position
         enemy_pos = self._EnemyPos(obs)  # Red one position
@@ -89,7 +95,7 @@ class CogEnvDecoder:
         action_tuple = ActionTuple()
         action_tuple.add_continuous(action)
         self._env._env.set_actions(self._env.name, action_tuple)
-        '''
+
         decision_step, terminal_step = self._env._env.get_steps(self._env.name)
         self._env._check_agents(max(len(decision_step), len(terminal_step)))
         #print(self._env.name)
@@ -99,7 +105,8 @@ class CogEnvDecoder:
             return self._env._single_step(terminal_step)
         else:
             return self._env._single_step(decision_step)
-        '''
+
+
     def step_action(self, action):
         #obs, reward, done, info = self.action_transfer(action)
         obs, reward, done, info = self._env.step(action)
@@ -150,55 +157,6 @@ class CogEnvDecoder:
             self.last_depth_frame = depth_img
         return depth_img
 
-    def _get_obs(self, obs):
-        img = np.zeros((400, 400, 3), np.uint8)
-        # end_position = (math.floor(obs[0]*100),math.floor(obs[1]*100))
-        # print("我是end_position:",end_position)
-        # cv.circle(img, end_position, 2, (0, 0, 255), 4)#BGR
-        # ptStart = (math.floor(obs[2]*100),math.floor(obs[3]*100))
-        ptStart = (200, 200)
-        # print("我是ptStart:",ptStart)
-        robot_angle = obs[2]
-        yaw = 0
-        test_yaw = []
-        vector = []
-        vector.append(obs[0])
-        vector.append(obs[1])
-        vector.append(obs[2])
-        vector.append(obs[3])
-        vector.append(obs[4])
-        vector.append(obs[5])
-        vector.append(obs[6])
-        for i in range(len(obs)):
-            if i < num_vector:
-                continue
-            elif i > 6 and i < 120:
-                yaw = i - num_vector
-                # yaw = 0
-
-            else:
-                yaw = i + 130
-                # yaw = 0
-
-            late_yaw = 90 / 57.3 - (robot_angle - yaw / 57.3)
-            # test_yaw.append(late_yaw)
-            # print(i)
-            # print(len(test_yaw))
-            distance = obs[i]
-            ptEnd = (math.floor(distance * math.cos(late_yaw) * 100) + 200,
-                     math.floor(distance * math.sin(late_yaw) * 100) + 200)
-            point_color = (0, 255, 0)
-            thickness = 1
-            lineType = 4
-            cv.line(img, ptStart, ptEnd, point_color, thickness, lineType)
-            # cv.namedWindow("image")
-        img = cv.flip(img, 0)
-        # print(len(test_yaw))
-        # cv.imshow('image', img)
-        # cv.waitKey(600)
-        # cv.destroyAllWindows()
-        return {'image': img, 'vector': np.array(vector)}
-        # return img
 
     def _GetImg(self, imgData):
         img_length = int(imgData[100000])
@@ -307,6 +265,7 @@ class CogEnvDecoder:
         #print('1')
         while True:
             self._env._env.step()
+            '''
             decision_step, terminal_step = self._env._env.get_steps(self._env.name)
             self._env._check_agents(max(len(decision_step), len(terminal_step)))
             # print(self._env.name)
@@ -317,17 +276,63 @@ class CogEnvDecoder:
             else:
                 self._obs, self._reward, self._done, self._info =  self._env._single_step(decision_step)
             #time.sleep(0.02)
+            '''
+            time.sleep(0.02)
             if self._end_thread == True:
                 return
 
+    def _thread_step_action(self):
+        done = False
+        while done == False and self._end_thread == False:
+            #print(done)
+            obs, reward, done, info = self._env.step(self._action)
+            img = self.read_img()
+            depth_img = self.read_depth_img()
+            self_pos = self._GetSelfPos(obs)  # Blue one Position
+            enemy_pos = self._EnemyPos(obs)  # Red one position
+            goal1 = self._GetGoal1Pos(obs)  # Goal 1 position, whether it has been activated
+            goal2 = self._GetGoal2Pos(obs)  # Goal 2 position, whether it has been activated
+            goal3 = self._GetGoal3Pos(obs)  # Goal 3 position, whether it has been activated
+            goal4 = self._GetGoal4Pos(obs)  # Goal 4 position, whether it has been activated
+            goal5 = self._GetGoal5Pos(obs)  # Goal 5 position, whether it has been activated
+            flag_ach = self._AchievedGoals(obs)  # Num of goals have been achieved
+            enemy_act = self._EnemyStatus(obs)  # Whether enemy has been activated
+            enemy_info = self._EnemyInfo(obs)  # Red one remaining HP & bullets
+            score = self._Score(obs)  # Current score
+            self_info = self._SelfInfo(obs)  # Blue one remaining HP & bullet
+            dmg = self._DmgCaused(obs)  # blue one caused damage to red one
+            time_taken = self._TimeTaken(obs)  # Time passed in the round
+            collision_info = self._CollCondtion(obs)  # collision times and continuous collision time
+            final_obs = [img, self_pos, enemy_pos, self_info, goal1, goal2, goal3, goal4, goal5, collision_info,
+                         depth_img]
+            judge_result = [score, flag_ach, enemy_act, enemy_info, dmg, time_taken]
+            self._obs = final_obs
+            self._reward = reward
+            self._done = done
+            self._info = [info, judge_result]
 
 
 
     def step_thread_begin(self):
-        self._thread = Thread(target=self._thread_step)
-        #print('2')
+        #self._thread = Thread(target=self._thread_step)
+        self._thread = Thread(target=self._thread_step_action)
+
         self._thread.start()
         #print('3')
         #self._thread.join()
         #print('4')
 
+    def set_action(self, action):
+        self._action = action
+
+    def get_obs(self):
+        return self._obs
+
+    def get_reward(self):
+        return self._reward
+
+    def get_done(self):
+        return self._done
+
+    def get_info(self):
+        return self._info
\ No newline at end of file
